How to run the examples
=======================

1. `just download-data` to download the testing data
2. `just up postgres` to launch the postgres instance

Then:

```bash
python local_cache.py
```



